==> haskell-hedgehog-0.6-26-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hedgehog.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hedgehog
version: 0.6
id: hedgehog-0.6-K6gpRgM6v4d3URsFgivm2R
key: hedgehog-0.6-K6gpRgM6v4d3URsFgivm2R
license: BSD-3-Clause
maintainer: Jacob Stanley <jacob@stanley.io>
author: Jacob Stanley
homepage: https://hedgehog.qa
synopsis: Hedgehog will eat all your bugs.
description:
    Hedgehog is a modern property-based testing system, in the spirit of
    QuickCheck. Hedgehog uses integrated shrinking, so shrinks obey the
    invariants of generated values by construction.
    .
    To get started quickly, see the examples:
    <https://github.com/hedgehogqa/haskell-hedgehog/tree/master/hedgehog-example>
category: Testing
abi: e3f71cd000b0884e96072957025922f9
exposed: True
exposed-modules:
    Hedgehog Hedgehog.Gen Hedgehog.Internal.Config
    Hedgehog.Internal.Discovery Hedgehog.Internal.Distributive
    Hedgehog.Internal.Exception Hedgehog.Internal.Gen
    Hedgehog.Internal.HTraversable Hedgehog.Internal.Opaque
    Hedgehog.Internal.Property Hedgehog.Internal.Queue
    Hedgehog.Internal.Range Hedgehog.Internal.Region
    Hedgehog.Internal.Report Hedgehog.Internal.Runner
    Hedgehog.Internal.Seed Hedgehog.Internal.Show
    Hedgehog.Internal.Shrink Hedgehog.Internal.Source
    Hedgehog.Internal.State Hedgehog.Internal.TH Hedgehog.Internal.Tree
    Hedgehog.Internal.Tripping Hedgehog.Range
import-dirs: /usr/lib/ghc-8.4.3/site-local/hedgehog-0.6
library-dirs: /usr/lib/ghc-8.4.3/site-local/hedgehog-0.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/hedgehog-0.6
hs-libraries: HShedgehog-0.6-K6gpRgM6v4d3URsFgivm2R
depends:
    base-4.11.1.0 ansi-terminal-0.8.0.4-4zlOvCKnE9eI77dRbIqIB1
    async-2.2.1-B6m2kYywRJu7nicgTBxsJe bytestring-0.10.8.2
    concurrent-output-1.10.6-Eczdtww6ZmWHkxoAWdo20D containers-0.5.11.0
    directory-1.3.1.5 exceptions-0.10.0-391qhPSiPEU3NJgxhfdaPf
    lifted-async-0.10.0.2-5rUZGw6PjDJHkbKDeX5P4x
    mmorph-1.1.2-u5n0PR0ucK5U9RRLpSUlt
    monad-control-1.0.2.3-I3eeoimEMDTINIqXKgCbLk mtl-2.2.2
    pretty-show-1.7-8bRRNOzyOi99X2ErRO7kao
    primitive-0.6.4.0-39Pwmm1zkQX6bM7xFUT3Jc
    random-1.1-9LLJAJa4iQFLJiLXBOBXBV
    resourcet-1.2.1-LmgqSpZgtYc1CYRXUZoy4I stm-2.4.5.0
    template-haskell-2.13.0.0 text-1.2.3.0
    th-lift-0.7.10-88ozaMeoe8eDZSlyIjheFa time-1.8.0.2
    transformers-0.5.5.0
    transformers-base-0.4.5.2-5YBw5fGTiDqHDjkVkrHRIb
    wl-pprint-annotated-0.1.0.0-FgIgnJvxePmJmjLg9RbQxb unix-2.7.2.2
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             ansi-terminal-0.8.0.4-4zlOvCKnE9eI77dRbIqIB1=3720aeddf087c27668b5c651df34c2d3
             async-2.2.1-B6m2kYywRJu7nicgTBxsJe=32776142fda961cc693aa4db742773f9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             concurrent-output-1.10.6-Eczdtww6ZmWHkxoAWdo20D=9b63789c52a04d6652a53d86d1761383
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             exceptions-0.10.0-391qhPSiPEU3NJgxhfdaPf=7910067871295cb7f4f6699a852863a6
             lifted-async-0.10.0.2-5rUZGw6PjDJHkbKDeX5P4x=6402cc8a85f1f7c1ec1561b9fd11259f
             mmorph-1.1.2-u5n0PR0ucK5U9RRLpSUlt=a11d1b6072309591a730a4f5ac739aa1
             monad-control-1.0.2.3-I3eeoimEMDTINIqXKgCbLk=7b91fe2931b6520a589ebb0da769a2de
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             pretty-show-1.7-8bRRNOzyOi99X2ErRO7kao=7f72f065bf630927a07ec77462e0c52e
             primitive-0.6.4.0-39Pwmm1zkQX6bM7xFUT3Jc=0a8d9e3ca28de3a4ac62e5f0044fa23c
             random-1.1-9LLJAJa4iQFLJiLXBOBXBV=2cade9e72fa19fe7a43e5ace84505d9f
             resourcet-1.2.1-LmgqSpZgtYc1CYRXUZoy4I=3fbb0f35b28cf76949df3af0a83627ff
             stm-2.4.5.0=4e743cb5a370ac3fbade528432951c3f
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             th-lift-0.7.10-88ozaMeoe8eDZSlyIjheFa=60d068a969a5d731636a40e25634c1aa
             time-1.8.0.2=042930fb6746cbaf3bc794f817f8a6b2
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             transformers-base-0.4.5.2-5YBw5fGTiDqHDjkVkrHRIb=b60c703c8501b255d99b1477d141017d
             wl-pprint-annotated-0.1.0.0-FgIgnJvxePmJmjLg9RbQxb=5b08ea9ef499d3d7d8cd2bfb880de5fe
             unix-2.7.2.2=f81aa481840dadf9c364a1cea96978c0
haddock-interfaces: /usr/share/doc/haskell-hedgehog/html/hedgehog.haddock
haddock-html: /usr/share/doc/haskell-hedgehog/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hedgehog-0.6-27-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hedgehog.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hedgehog
version: 0.6
id: hedgehog-0.6-DOhPvIODWfR8YaQIHKQrqM
key: hedgehog-0.6-DOhPvIODWfR8YaQIHKQrqM
license: BSD-3-Clause
maintainer: Jacob Stanley <jacob@stanley.io>
author: Jacob Stanley
homepage: https://hedgehog.qa
synopsis: Hedgehog will eat all your bugs.
description:
    Hedgehog is a modern property-based testing system, in the spirit of
    QuickCheck. Hedgehog uses integrated shrinking, so shrinks obey the
    invariants of generated values by construction.
    .
    To get started quickly, see the examples:
    <https://github.com/hedgehogqa/haskell-hedgehog/tree/master/hedgehog-example>
category: Testing
abi: 1f53b5c7e9059f80fa8f804b10283555
exposed: True
exposed-modules:
    Hedgehog Hedgehog.Gen Hedgehog.Internal.Config
    Hedgehog.Internal.Discovery Hedgehog.Internal.Distributive
    Hedgehog.Internal.Exception Hedgehog.Internal.Gen
    Hedgehog.Internal.HTraversable Hedgehog.Internal.Opaque
    Hedgehog.Internal.Property Hedgehog.Internal.Queue
    Hedgehog.Internal.Range Hedgehog.Internal.Region
    Hedgehog.Internal.Report Hedgehog.Internal.Runner
    Hedgehog.Internal.Seed Hedgehog.Internal.Show
    Hedgehog.Internal.Shrink Hedgehog.Internal.Source
    Hedgehog.Internal.State Hedgehog.Internal.TH Hedgehog.Internal.Tree
    Hedgehog.Internal.Tripping Hedgehog.Range
import-dirs: /usr/lib/ghc-8.4.3/site-local/hedgehog-0.6
library-dirs: /usr/lib/ghc-8.4.3/site-local/hedgehog-0.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/hedgehog-0.6
hs-libraries: HShedgehog-0.6-DOhPvIODWfR8YaQIHKQrqM
depends:
    base-4.11.1.0 ansi-terminal-0.8.0.4-4zlOvCKnE9eI77dRbIqIB1
    async-2.2.1-B6m2kYywRJu7nicgTBxsJe bytestring-0.10.8.2
    concurrent-output-1.10.6-Eczdtww6ZmWHkxoAWdo20D containers-0.5.11.0
    directory-1.3.1.5 exceptions-0.10.0-391qhPSiPEU3NJgxhfdaPf
    lifted-async-0.10.0.2-7rOaQ3ST3UK8WjGGkn54mf
    mmorph-1.1.2-u5n0PR0ucK5U9RRLpSUlt
    monad-control-1.0.2.3-I3eeoimEMDTINIqXKgCbLk mtl-2.2.2
    pretty-show-1.8.1-7H0L2aT0WSVIsk7RM7bmlH
    primitive-0.6.4.0-39Pwmm1zkQX6bM7xFUT3Jc
    random-1.1-9LLJAJa4iQFLJiLXBOBXBV
    resourcet-1.2.1-LmgqSpZgtYc1CYRXUZoy4I stm-2.4.5.0
    template-haskell-2.13.0.0 text-1.2.3.0
    th-lift-0.7.10-88ozaMeoe8eDZSlyIjheFa time-1.8.0.2
    transformers-0.5.5.0
    transformers-base-0.4.5.2-5YBw5fGTiDqHDjkVkrHRIb
    wl-pprint-annotated-0.1.0.0-FgIgnJvxePmJmjLg9RbQxb unix-2.7.2.2
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             ansi-terminal-0.8.0.4-4zlOvCKnE9eI77dRbIqIB1=3720aeddf087c27668b5c651df34c2d3
             async-2.2.1-B6m2kYywRJu7nicgTBxsJe=32776142fda961cc693aa4db742773f9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             concurrent-output-1.10.6-Eczdtww6ZmWHkxoAWdo20D=9b63789c52a04d6652a53d86d1761383
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             exceptions-0.10.0-391qhPSiPEU3NJgxhfdaPf=7910067871295cb7f4f6699a852863a6
             lifted-async-0.10.0.2-7rOaQ3ST3UK8WjGGkn54mf=17fb37e77840e13d76c82b3eb091f48e
             mmorph-1.1.2-u5n0PR0ucK5U9RRLpSUlt=a11d1b6072309591a730a4f5ac739aa1
             monad-control-1.0.2.3-I3eeoimEMDTINIqXKgCbLk=7b91fe2931b6520a589ebb0da769a2de
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             pretty-show-1.8.1-7H0L2aT0WSVIsk7RM7bmlH=8a070f0bc695078286ea307e4ff7a440
             primitive-0.6.4.0-39Pwmm1zkQX6bM7xFUT3Jc=0a8d9e3ca28de3a4ac62e5f0044fa23c
             random-1.1-9LLJAJa4iQFLJiLXBOBXBV=2cade9e72fa19fe7a43e5ace84505d9f
             resourcet-1.2.1-LmgqSpZgtYc1CYRXUZoy4I=3fbb0f35b28cf76949df3af0a83627ff
             stm-2.4.5.0=4e743cb5a370ac3fbade528432951c3f
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             th-lift-0.7.10-88ozaMeoe8eDZSlyIjheFa=60d068a969a5d731636a40e25634c1aa
             time-1.8.0.2=042930fb6746cbaf3bc794f817f8a6b2
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             transformers-base-0.4.5.2-5YBw5fGTiDqHDjkVkrHRIb=b60c703c8501b255d99b1477d141017d
             wl-pprint-annotated-0.1.0.0-FgIgnJvxePmJmjLg9RbQxb=5b08ea9ef499d3d7d8cd2bfb880de5fe
             unix-2.7.2.2=f81aa481840dadf9c364a1cea96978c0
haddock-interfaces: /usr/share/doc/haskell-hedgehog/html/hedgehog.haddock
haddock-html: /usr/share/doc/haskell-hedgehog/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
